@@ -5,20 +5,15 @@ use RTx::Shredder::Constants;
 use RTx::Shredder::Exceptions;
 use RTx::Shredder::Dependencies;
 
-sub Dependencies
+sub __DependsOn
 {
 	my $self = shift;
 	my %args = (
 			Shredder => undef,
-			Flags => DEPENDS_ON,
+			Dependencies => undef,
 			@_,
 		   );
-
-	unless( $self->id ) {
-		RTx::Shredder::Exception->throw('Object is not loaded');
-	}
-
-	my $deps = RTx::Shredder::Dependencies->new();
+	my $deps = $args{'Dependencies'};
 	my $list = [];
 
 # Tickets which were merged in
@@ -34,10 +29,6 @@ sub Dependencies
 	$objs->Limit( FIELD => 'Instance', VALUE => $self->Id );
 	push( @$list, $objs );
 
-# Transactions
-	$objs = $self->Transactions;
-	push( @$list, $objs );
-
 # Links
 # Native API calls that select using Ticket's URI
 	push( @$list, $self->_Links( 'Base' ) );
@@ -51,11 +42,6 @@ sub Dependencies
 	$objs->Limit( FIELD => 'LocalTarget', VALUE => $self->Id );
 	push( @$list, $objs );
 
-# Ticket custom field values
-	$objs = RT::TicketCustomFieldValues->new( $self->CurrentUser );
-	$objs->LimitToTicket( $self->Id() );
-	push( @$list, $objs );
-
 #TODO: Users, Queues if we wish export tool
 	$deps->_PushDependencies(
 			BaseObj => $self,
@@ -64,7 +50,38 @@ sub Dependencies
 			Shredder => $args{'Shredder'}
 		);
 
-	return $deps;
+	return $self->SUPER::__DependsOn( %args );
+}
+
+sub __Relates
+{
+	my $self = shift;
+	my %args = (
+			Shredder => undef,
+			Dependencies => undef,
+			@_,
+		   );
+	my $deps = $args{'Dependencies'};
+	my $list = [];
+
+# Queue
+	my $obj = $self->QueueObj;
+	if( $obj && defined $obj->id ) {
+		push( @$list, $obj );
+	} else {
+		my $rec = $args{'Shredder'}->GetRecord( Object => $self );
+		$self = $rec->{'Object'};
+		$rec->{'State'} |= INVALID;
+		$rec->{'Description'} = "Have no related Queue #". $self->Queue ." object";
+	}
+
+	$deps->_PushDependencies(
+			BaseObj => $self,
+			Flags => RELATES,
+			TargetObjs => $list,
+			Shredder => $args{'Shredder'}
+		);
+	return $self->SUPER::__Relates( %args );
 }
 
 1;
